Documentation
¶
Index ¶
- Constants
- func DecryptBytes(data []byte, secretKeys ...string) ([]byte, error)
- func EncryptBytes(data []byte, publicKeys ...string) ([]byte, error)
- func GenHybridKeyPair() (secretKey string, publicKey string, err error)
- func GenX25519KeyPair() (secretKey string, publicKey string, err error)
- func Main(args []string)
- func SetGlobalSecretKeys(secretKeys ...string)
- func ToPublicKeys(secretKeys ...string) (publicKeys []string, err error)
- func VerityPublicKeys(publicKeys ...string) error
- func VeritySecretKeys(secretKeys ...string) error
Constants ¶
const FileHeader = armor.Header
Variables ¶
This section is empty.
Functions ¶
func DecryptBytes ¶
DecryptBytes decrypt age armor format encrypted data if not the age armor format, return original data
func EncryptBytes ¶
EncryptBytes encrypt data with age armor format
func GenHybridKeyPair ¶
GenHybridKeyPair generate mlkem768-x25519 hybrid post-quantum recipient type age-secret-key and age-public-key
func GenX25519KeyPair ¶
GenX25519KeyPair generate x25519 recipient type age-secret-key and age-public-key
func SetGlobalSecretKeys ¶
func SetGlobalSecretKeys(secretKeys ...string)
SetGlobalSecretKeys set global secret keys, which will be used when decrypting
func ToPublicKeys ¶
ToPublicKeys convert age-secret-key to age-public-key
func VerityPublicKeys ¶
VerityPublicKeys check if the public key is valid
func VeritySecretKeys ¶
VeritySecretKeys check if the secret key is valid
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.